//
// C++ Implementation: kpgnoticer
//
// Description: 
//
//
// Author: Lumir Vanek <lvanek@users.sourceforge.net>, (C) 2008
//
// Copyright: See COPYING file that comes with this distribution
//
//
#include "kpgnoticer.h"

// include files for Qt
#include <qstring.h>
#include <qtextcodec.h>

// include files for KDE
#include <kdebug.h>


KPGNoticer::KPGNoticer(QTextCodec *pTextCodec)
{	
	m_pTextCodec = pTextCodec;
}

void KPGNoticer::operator()(const char szMsg[]) throw ()
{
	emit sigNotice(m_pTextCodec->toUnicode(szMsg));
}

KPGNoticer::~KPGNoticer() throw ()
{
	disconnect();
}
